<?php
namespace Creativeiconbox;

use Creativeiconbox\PageSettings\Page_Settings;
define( "BWDIB_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDIB_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

class Classbwdibiconbox {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdib_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdib_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdib_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdib_the_pricing_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdib-iconbox.php' );
	}

	public function bwdib_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDIBIconbox() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdib-icon-box-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdib_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdib-icon-box-category',
			[
				'title' => esc_html__( 'BWD Icon Box', 'bwdib-icon-box' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdib_all_assets_for_the_public(){
		wp_enqueue_style( 'bwdib-fontAwesome', BWDIB_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/font-awesome.min.css', array(), '6.5.0', 'all' );
		wp_enqueue_style( 'bwdib-bootstrap', BWDIB_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/font-awesome.min.css', array(), '6.5.0', 'all' );
		wp_enqueue_style( 'bwdib-main-style', BWDIB_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css', array(), '6.5.0', 'all' );
	}
	public function bwdib_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdib_icon_box_admin_icon_css' => array('bwdib_path_admin_define'=>BWDIB_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdib_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdib_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdib_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdib_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdib_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdib_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
Classbwdibiconbox::instance();